server

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 16, 2025 License: MIT Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PeerAwareConn

type PeerAwareConn struct {
	net.Conn
	// contains filtered or unexported fields
}

PeerAwareConn wraps a connection with extracted peer information

func (*PeerAwareConn) GetPeerInfo

func (c *PeerAwareConn) GetPeerInfo() *security.PeerInfo

GetPeerInfo returns the extracted peer information

type PeerAwareTLSListener

type PeerAwareTLSListener struct {
	// contains filtered or unexported fields
}

PeerAwareTLSListener wraps a Unix listener to extract peer info before TLS

func (*PeerAwareTLSListener) Accept

func (l *PeerAwareTLSListener) Accept() (net.Conn, error)

Accept accepts a connection and extracts peer info before TLS wrapping

func (*PeerAwareTLSListener) Addr

func (l *PeerAwareTLSListener) Addr() net.Addr

Addr returns the listener's network address

func (*PeerAwareTLSListener) Close

func (l *PeerAwareTLSListener) Close() error

Close closes the underlying listener

type Server

type Server struct {
	SockPath    string
	Token       string
	Cache       *cache.Cache
	Backend     backend.Backend
	Session     *session.Manager
	Policy      policy.Policy
	PolicyPath  string
	AuditLogger *audit.Logger
	RateLimiter *rate.Limiter
	Verbose     bool
	// contains filtered or unexported fields
}

func (*Server) CacheTTL

func (s *Server) CacheTTL() time.Duration

func (*Server) Serve

func (s *Server) Serve(ctx context.Context) error

Jump to