Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PeerAwareConn ¶
PeerAwareConn wraps a connection with extracted peer information
func (*PeerAwareConn) GetPeerInfo ¶
func (c *PeerAwareConn) GetPeerInfo() *security.PeerInfo
GetPeerInfo returns the extracted peer information
type PeerAwareTLSListener ¶
type PeerAwareTLSListener struct {
// contains filtered or unexported fields
}
PeerAwareTLSListener wraps a Unix listener to extract peer info before TLS
func (*PeerAwareTLSListener) Accept ¶
func (l *PeerAwareTLSListener) Accept() (net.Conn, error)
Accept accepts a connection and extracts peer info before TLS wrapping
func (*PeerAwareTLSListener) Addr ¶
func (l *PeerAwareTLSListener) Addr() net.Addr
Addr returns the listener's network address
func (*PeerAwareTLSListener) Close ¶
func (l *PeerAwareTLSListener) Close() error
Close closes the underlying listener
Click to show internal directories.
Click to hide internal directories.